#
# spec file for package opentofu
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define executable_name tofu

Name:           opentofu
Version:        1.8.7
Release:        1.1
Summary:        Declaratively manage your cloud infrastructure
License:        MPL-2.0
Group:          System/Management
URL:            https://github.com/opentofu/opentofu
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
Source99:       opentofu-rpmlintrc
BuildRequires:  bash-completion
BuildRequires:  golang-packaging
BuildRequires:  golang(API) >= 1.22.8
# See: https://github.com/hashicorp/opentofu/issues/22807
ExcludeArch:    %{ix86} %{arm}

%description
Fork of Terraform

OpenTofu is an OSS tool for building, changing, and versioning infrastructure
safely and efficiently. OpenTofu can manage existing and popular service
providers as well as custom in-house solutions.

The key features of OpenTofu are:
- Infrastructure as Code: Infrastructure is described using a high-level
  configuration syntax. This allows a blueprint of your datacenter to be
  versioned and treated as you would any other code. Additionally, infrastructure
  can be shared and re-used.
- Execution Plans: OpenTofu has a "planning" step where it generates an
  execution plan. The execution plan shows what OpenTofu will do when you call
  apply. This lets you avoid any surprises when OpenTofu manipulates
  infrastructure.
- Resource Graph: OpenTofu builds a graph of all your resources, and
  parallelizes the creation and modification of any non-dependent resources.
  Because of this, OpenTofu builds infrastructure as efficiently as possible, and
  operators get insight into dependencies in their infrastructure.
- Change Automation: Complex changesets can be applied to your infrastructure
  with minimal human interaction. With the previously mentioned execution plan
  and resource graph, you know exactly what OpenTofu will change and in what
  order, avoiding many possible human errors.

%prep
%autosetup -p 1 -a 1

%build
go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags "-w -s -X github.com/opentofu/opentofu/version.dev=no -X github.com/opentofu/opentofu/version.Version=%{version}" \
   -o bin/%{executable_name} ./cmd/tofu

%install
# Install the binary.
install -D -m 0755 bin/%{executable_name} "%{buildroot}/%{_bindir}/%{executable_name}"
mkdir -p %{buildroot}%{_datadir}/bash-completion/completions/
cat > %{buildroot}%{_datadir}/bash-completion/completions/%{executable_name} <<EOF
complete -C %{_bindir}/%{executable_name} %{executable_name}
EOF

%files
%license LICENSE
%doc CHANGELOG.md README.md
%{_bindir}/%{executable_name}
%{_datadir}/bash-completion/completions/%{executable_name}

%changelog
* Fri Dec  6 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.8.7:
  * BUG FIXES:
  - Error messages related to validation of sensitive input
    variables will no longer disclose the sensitive value in the
    UI. (#2219)
  - Changes to encryption configuration now auto-apply the
    migration (#2232)
  - Updated github.com/golang-jwt/jwt/v4 from 4.4.2 to 4.5.1 to
    make security scanners happy (no vulnerability, see #2179)
  - tofu test is now setting nulls for dynamic type when
    generating mock values. (#2245)
  - Variables declared in test files are now taking into account
    type default values. (#2244)
* Fri Nov 22 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.8.6:
  * update 1.8 versions (#2211)
  * fix changelog for 1.8.6 (#2207)
  * [BACKPORT] add missing changelog entry for http backend logging
    (#2206) (#2209)
  * Bump golang version to 1.22.8 (address CVE-2024-34156) (#2050)
    (#2182)
  * [BACKPORT] fix mock type conversion in tofu test (#2144)
    (#2197)
  * [BACKPORT] fix mock provider validation (#2140) (#2196)
  * [BACKPORT] Add DEBUG-level logging to the "http" state storage
    backend (#2120) (#2192)
  * [BACKPORT] pin node version for docusaurus build (#2177)
    (#2194)
* Tue Nov 12 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.8.5:
  * Prepare for the v1.8.6 release (#2137)
  * v1.8 Backport: Fix regression of backend reinit detection when
    backend schema has required arguments (#2135)
  * Partially unknown provider functions arguments fixed (#2127)
    (#2133)
* Thu Oct 24 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.8.4:
  * Bumped versionfile for 1.8 (#2097)
  * Backport recent changes to v1.8 (#2093)
  * CHANGELOG entry for #2055 and #2060
  * command/init: Support static eval for backend config migration
    check
* Fri Oct  4 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.8.3:
  * Backport 1.8 handle static variable secrets (#2046)
  * Make sure test vars are only processed during test commands
    (#2040)
  * Fix Terraform Version in 1.8.x Migration Guide (#1987) (#2000)
  * Update docs version message (#1990) (#1997)
* Tue Sep 10 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.8.2:
  * Update version and changelog to 1.8.2 (#1968)
  * Backport bump go version to v1.8 (#1966)
  * Better handling of key_provider references (#1921) (#1965)
  * fix inconsistent sidebar title of functions on v1.8 branch
    (#1907)
  * Fix Docusaurus "broken link" warnings on 1.8 branch of docs
    (#1884) (#1898)
* Wed Aug  7 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.8.1:
  * Bump to 1.8.1 (#1893)
  * Fix missing module source panic (#1888) (#1889)
  * Backport/v1.8/1876 (#1886)
  * 1666/tacos website docs backport to 1.8 (#1883)
  * Fix 1.8 release workers (#1870)
  * Switch to alternate runner group (#1868)
  * Run releases on larger workers. (#1587) (#1867)
* Mon Jul 29 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.8.0:
  * What's New?
  - Early variable/locals evaluation
  - Provider mocking in tofu test
  - Resource overrides in tofu test
  - Override files for OpenTofu: keeping compatibility
  - Deprecation: use_legacy_workflow has been removed from the S3
    backend-backend
  See the launch post on our blog:
  https://opentofu.org/blog/opentofu-1-8-0/
  For all the features, see the detailed changelog:
  https://github.com/opentofu/opentofu/blob/v1.8.0/CHANGELOG.md
  You can find the full diff here:
  https://github.com/opentofu/opentofu/compare/v1.7..v1.8.0
* Wed Jul 10 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.7.3:
  * Updating the VERSION file to 1.7.3. (#1783)
  * Adding 1.7.3 changelog as released (#1780)
  * Backporting release workflow changes (#1764)
  * [Backports/1.7] Support lower-case http/https_proxy env
    variables in S3 backend (#1741)
* Mon Jun  3 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.7.2:
  This is a bugfix release and we encourage all OpenTofu 1.7.1
  users to upgrade.
  * Fixed - authorization header is not included for HTTP backends
    (#1656)
  * Fixed bug in import 'to' parsing in JSON configurations (#1665)
  * Fix bug where provider functions were unusable in variables and
    outputs (#1689)
* Fri May 17 2024 Christian Goll <cgoll@suse.com>
- added global bash completion
* Wed May  8 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.7.1:
  * Fixing changelog for 1.7.1
  * Backport[v1.7] 1.7.1 docs (#1630)
  * Backport Fixed tofu test when module has no resource (#1628)
  * Backport Fix for tofu init failure when test have spaces in
    their name (#1627)
  * Backport: Allow unconfigured provider functions in test context
    to 1.7.1 (#1621)
  * Backport encryption fixes to 1.7.1 (#1620)
  * Fix workflow.
  * Run releases on larger workers. (#1587)
  * Backport[v1.7] Linking provider-defined functions from the
    what's new page (#1584) (#1585)
* Tue Apr 30 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.7.0:
  We're proud to announce that OpenTofu 1.7.0 is now officially
  out!
  What’s New?
  * State Encryption - Protect your precious state files with
    end-to-end encryption.
  * Dynamic Provider-defined Functions - Author custom functions as
    part of providers.
  * Declarative removed Blocks - No more fighting with the CLI,
    execute your removals declaratively!
  * Loopable Import Blocks - Streamline importing multiple
    resources.
  * ...and much, much more!
  See the launch post on our blog:
  https://opentofu.org/blog/opentofu-1-7-0/
  For all the features, see the detailed changelog:
  https://github.com/opentofu/opentofu/blob/ba4c3a5b462129cd61644a3ae760d746dc12b8fc/CHANGELOG.md
* Fri Feb 23 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.6.2:
  * Prepare 1.6.2 update (#1296)
  * Backports: Problem referencing output from test run in local
    variables block (#1254) (#1293)
  * Backport: Add Community Supported Architectures Section to
    Install Docs -… (#1257)
  * Backport of Resolve more inconsistencies in 32-bit systems
    (#1214) (#1226)
  * Backport: Fix typo in standalone-install.sh (#1186) (#1187)
* Fri Jan 26 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.6.1:
  * Bump version and update changelog. (#1183)
  * Improve stability on 32-bit architectures (#1154)
  * Add Environment Variables to plugin signing page (#1159)
  * Add changelog entry for #1141 (#1142)
  * Fix running `tofu show` and `tofu state show` with state files
    that reference Terraform registry providers. (#1141)
  * #1129 backport (#1133)
  * Add Global Schema Cache fix to CHANGELOG.md
  * Fix Global Schema Cache not working in provider acceptance
    tests (#1054)
  * Allow known references in import blocks (#1105) (#1114)
  * Backporting #1110 (#1111)
  * Update references of tofu version to 1.6.0 ready for release
    (#1082)
  * docs: fix wget https://get.opentofu.org command (#1095) (#1096)
  * Updating install instructions to include the installer script
    (#1070) (#1094)
  * Pull in 1.6.x-docs into v1.6 (#1092)
* Wed Jan 10 2024 opensuse_buildservice@ojkastl.de
- Update to version v1.6.0:
  Time for the big release! OpenTofu 1.6.0 is now stable!
  Read more about this on
  [our blog](https://opentofu.org/blog/opentofu-is-going-ga)!
  This release is a drop-in replacement, and you can follow our
  simple migration guide to start using it with your existing
  infrastructure configurations.
  If you'd like to read about all the changes introduced, check out
  the detailed changelog.
  https://github.com/opentofu/opentofu/blob/v1.6/CHANGELOG.md
* Tue Dec 19 2023 dmueller@suse.com
- Update to version 1.6.0~rc1:
  * Bump version. (#1038)
  * Fixes #980: Remove Packagecloud instructions (#1036)
  * Fixes #908: Migration guide (#1021)
  * Re-add ssh and bash to Dockerfile (#1034)
* Sat Dec 16 2023 kastl@b1-systems.de
- Update to version 1.6.0~beta5:
  * Fixed fix for fix of GPG (#1024)
  * Fixing release tag gating (#1023)
  * Parametrized release (#1022)
  * Bump version. (#1020)
  * GPG build fixes (#1019)
  * Weekly update. (#1015)
  * Update changelog for hashicorp / opentofu only warning (#1016)
  * Add a warning when multiple likely forks of a provider are
    detected (#1009)
  * Fix renaming mistakes in docs (#1012)
  * Add Technical Steering Committee Summary for 2023-12-11 (#1010)
  * Fixes #915: GPG signing of Debian and RPM packages (#1000)
  * Replace additional Terraform -> OpenTofu (#1007)
  * Find additional places where terraform should be replaced with
    tofu (#1001)
  * Improve unclear provider resolver error messages (#1003)
  * 898 consolidate and remove tfe addr [part 2] (#998)
* Tue Dec 12 2023 kastl@b1-systems.de
- Update to version 1.6.0~beta4:
  * Bump version. (#999)
  * Add gate for TFE tests that use the network (#997)
  * Revert "Fixes #898: Replace hashicorp and terraform references"
    (#995)
  * Add Technical Steering Committee Summary for 2023-12-05 (#990)
  * Testable Homebrew instructions (#984)
  * Update CHANGELOG with provider namespace change (#987)
* Fri Dec  8 2023 kastl@b1-systems.de
- Update to version 1.6.0~beta3:
  * Bump version. (#986)
  * Update brew install for Linux (#959)
  * Fixes #898: Replace hashicorp and terraform references (#973)
  * website: Better install instructions (GitHub actions compatible
    output) (#983)
  * 904 missing provider module message (#981)
  * Updated installation instructions to packages.opentofu.org
    (#978)
  * chore: add linux install instructions test to makefile (#976)
  * Weekly update 20231205 (#972)
  * website: Dev server (#971)
  * Adding Buildkite sponsorship remark (#969)
  * Fix goreleaser draft option. (#968)
* Tue Dec  5 2023 kastl@b1-systems.de
- Update to version 1.6.0~beta2:
  * Update CONTRIBUTING.md to remove hold-off message for alpha
    (#945)
  * Bump version for new beta. (#963)
  * Improve comments around the global and local provider schema
    cache. (#958)
  * Update aws-sdk-go-base and fix resulting type errors. (#957)
  * Make goreleaser create draft releases instead of full releases,
    so that we can customize the description. (#956)
  * Add gcs end-to-end tests to the makefile. (#955)
  * Fix global schema caching (#954)
  * Fixes #292: Fixing broken website build (#952)
  * Fixes #292: Testing feature documentation (#939)
* Thu Nov 30 2023 kastl@b1-systems.de
- Update to version 1.6.0~beta1:
  * Bump version to first beta. (#943)
  * docs: fix: quote URLs; add security & behaviorial opts (fixes
    [#936]) (#935)
  * Fixing broken docs page symlink (#934)
  * Add dependencies for integration tests with Kubernetes as
    backend (#933)
  * website: submodule/enable live editing (#890)
  * Add dependencies for integration tests with Consul as backend
    (#932)
  * Add Azure integration test runbook. (#924)
  * Change references to opentofu.org (#902)
  * Fixes #913: Incorrect installation instructions for RPM (#917)
  * Add definition of integration tests with Postgres backend
    (#920)
  * Add MAINTAINER and update CODEOWNERS (#919)
  * Align the module fetching logic with the OpenTofu registry v1
    protocol (#901)
  * Fixes #859: Removing apt and yum installation instructions
    (moved to intro section) (#903)
  * Weekly update for the 2023-11-21. (#905)
  * Fixes #539: Setting both "Type" and "NestedType" removes other
    validation error messages (#897)
  * Add `no_proxy` and `https_proxy` attributes to s3 backend
    schema (#896)
  * Add `tofu test` command definition (#886)
  * website: Split installation instructions (#887)
  * Fix workspaces configuration using environment varariable
    TF_WORKSPACE (#867)
  * Use correct location for LICENSE file during installation
    (opentofu instead of nfpm) (#889)
  * Weekly update 2023-11-15. (#883)
  * Fix S3 Remote State Backend Validation (#876)
  * Update s3 remote state tests (#865)
  * Add missing argument to PackageCloud install instructions
    (#873)
* Thu Nov 16 2023 kastl@b1-systems.de
- Update to version 1.6.0~alpha5:
  * Bump version for release. (#871)
  * Add GPG Expiration entry in the CHANGELOG (#870)
  * Updated changelog to reflect consistent spelling of the word
    initialization (#869)
  * Upload packages to PackageCloud during release action (#860)
  * S3 Client HeadObject requires SSE parameters (#864)
  * Move S3 CHANGELOG entries I added to S3 upgrade section (#862)
  * Remove draft CHANGELOG section of PR template (#861)
  * keep init wording consistent in internal/command/init.go (#855)
  * Allow expired provider pgp keys, with warning (#848)
  * Add link to installation guide to readme (#857)
  * Avoid mutating input config in node_resource_validate (#850)
  * Update hcl version to v2.19.1 (#852)
  * Pull in docker cross buildx tooling (#849)
* Fri Nov 10 2023 Johannes Kastl <kastl@b1-systems.de>
- properly report the version (otherwise this would report
  1.6.0-dev)
- rename the executable to 'tofu', to match upstream naming
* Fri Nov 10 2023 kastl@b1-systems.de
- Update to version 1.6.0~alpha4:
  * Address s3 compatible remote state issues + logging (#840)
  * Bump version file. (#845)
  * Update go-tfe to 1.36.0 (#844)
  * Add changelog that was missed in PR #830 (#843)
  * Fix crash during destroy planning due to validation (#830)
  * Revert PRs that introduced propogating contexts (#835)
  * Weekly update for the 2023-11-07. (#831)
  * Add Technical Steering Committee Summary for 2023-11-02 (#823)
  * Backend/S3: Update the `Put` method (#795)
  * Backend/S3: Add support for `skip_requesting_account_id` (#788)
  * Weekly update for the 2023-11-02 (#809)
  * Update user-agent from go-tfe to opentofu where go-tfe is used
    (#807)
  * Backend/S3: Custom Service Endpoint Configuration (#794)
  * Stop reading providers from the HashiCorp registry based on the
    statefile if not specified in code. (#773)
  * Backend/S3: Add support for `use_path_style` (#787)
  * Add DEBUGGING.md (#711)
  * Pass context to all statemgr.Locker operations (#789)
  * Pass context to all remote.Client operations (#786)
  * Make backend.Workspaces accept a context (#784)
  * Backend/S3: Add HTTP parameters for parity with AWS Provider
    (#770)
  * Make backend.DeleteWorkspace accept a context (#782)
  * Backend/S3: Allow specifying retry mode for AWS API requests
    (#769)
  * Backend/S3: Add support for overriding EC2 Metadata Service
    endpoint (#767)
  * Weekly update for the 2023-10-24 (#781)
  * Backend/S3: Allow use of an alternative region for STS
    operations (#768)
  * Backend/s3: Add support for `assume_role_with_web_identity`
    block (#759)
  * Make backend.StateMgr accept a context (#780)
  * Make backend.Configure accept a context (#779)
  * Backend/S3: Add support for custom CA bundle (#762)
  * backend/s3: skip account verification when no constraints given
    (#772)
  * Make backend.PrepareConfig accept a context (#777)
  * Make backend.ConfigSchema accept a context (#776)
  * Improve logging of global provider schema cache hits. (#766)
  * S3 backend add account ID whitelisting arguments (#760)
  * Backend/S3: Extract `assume_role` as a separate block (#754)
  * Added Security disclousure policy (#749)
  * Add comparison to Terraform link (#737)
  * Provide git for module installation (#751)
  * Upgrade AWS SDK (#701)
  * Update core team email. (#752)
* Thu Oct 19 2023 kastl@b1-systems.de
- Update to version 1.6.0~alpha3:
  * Fix goreleaser version to one that actually exists. (#744)
  * Fix typo in name of script. (#743)
  * Update version for new release. (#742)
  * Post weekly update for the 2023-10-17. (#740)
  * Update to be more consistent across operating systems. (#731)
  * Add installation instructions. (#730)
  * Fix: Global provider schema cache is never used (#719)
  * Build using golang 1.21 (#718)
  * Add the license to compare-release-versions.sh (#727)
  * (#721) remove reference to Hashicorp docker mirror in workflow
    (#723)
* Fri Oct  6 2023 Johannes Kastl <kastl@b1-systems.de>
- new package opentofu: OpenSource fork of Terraform
